@@ -9,6 +9,7 @@ from k8kat.res.base.kat_res import KatRes, MetricsDict
 from k8kat.res.base.label_set_expressions import label_conditions_to_expr
 from k8kat.res.pod.kat_pod import KP
 from k8kat.res.relation.relation import Relation
+from k8kat.utils.main import utils
 from k8kat.utils.main.class_property import classproperty
 from k8kat.utils.main.types import IntelDict
 
@@ -110,6 +111,10 @@ class KatDep(KatRes):
     pod_settle_states = list(map(KatPod.has_settled, pods))
     return len(pods) == 0 or set(pod_settle_states) == {True}
 
+  def events(self):
+    pod_events = [p.events() for p in self.pods()]
+    return utils.flatten(pod_events)
+
   @lru_cache(maxsize=128)
   def load_per_pod_metrics(self) -> List[MetricsDict]:
     """Loads the appropriate metrics dict from k8s metrics API."""
